@@ -52,31 +52,26 @@ setMethod(
 
       if (is_igraph(thisGraph)) {
         results[[i]] <- list()
-        results[[i]]$v <- data.frame(sapply(names(vertex_attr(thisGraph)), function(z) {
-          vertex_attr(thisGraph, z)
-        }), stringsAsFactors = FALSE)
-        results[[i]]$e <- data.frame(as_edgelist(thisGraph),
-          sapply(names(edge_attr(thisGraph)), function(z) {
-            edge_attr(thisGraph, z)
-          }),
-          stringsAsFactors = FALSE
-        )
-        edgeDfNames <- names(results[[i]]$e)
-        names(results[[i]]$e) <- c("e1", "e2", edgeDfNames[3:length(edgeDfNames)])
+        results[[i]]$v <- names(vertex_attr(thisGraph)) |>
+          sapply(FUN = function(z) vertex_attr(thisGraph, z)) |>
+          data.frame(stringsAsFactors = FALSE)
+
+        edgeAttr <- names(edge_attr(thisGraph)) |>
+          sapply(FUN = function(z) edge_attr(thisGraph, z)) |>
+          rbind()
+        results[[i]]$e <- as_edgelist(thisGraph) |>
+          data.frame(edgeAttr, stringsAsFactors = FALSE) |>
+          stats::setNames(c("e1", "e2", colnames(edgeAttr)))
 
         ## Clean-up storage mode structure of data.frames
-        results[[i]]$e <- as.data.frame(sapply(results[[i]]$e, as.character),
-          stringsAsFactors = FALSE
-        )
-        results[[i]]$v <- as.data.frame(sapply(results[[i]]$v, as.character),
-          stringsAsFactors = FALSE
-        )
-        results[[i]]$e <- as.data.frame(lapply(results[[i]]$e, function(z) {
-          type.convert(z, as.is = TRUE)
-        }), stringsAsFactors = FALSE)
-        results[[i]]$v <- as.data.frame(lapply(results[[i]]$v, function(z) {
-          type.convert(z, as.is = TRUE)
-        }), stringsAsFactors = FALSE)
+        results[[i]]$e <- sapply(results[[i]]$e, as.character) |>
+          as.data.frame(stringsAsFactors = FALSE)
+        results[[i]]$v <- sapply(results[[i]]$v, as.character) |>
+          as.data.frame(stringsAsFactors = FALSE)
+        results[[i]]$e <- lapply(results[[i]]$e, function(z) type.convert(z, as.is = TRUE)) |>
+          as.data.frame(stringsAsFactors = FALSE)
+        results[[i]]$v <- lapply(results[[i]]$v, function(z) type.convert(z, as.is = TRUE)) |>
+          as.data.frame(stringsAsFactors = FALSE)
       } else {
         results[[i]]$v <- NA
         results[[i]]$e <- NA
